TransactionResult class
Constructors
- TransactionResult({required String identifier, required TransactionType transactionType, required bool approved, TransactionError? error, bool signatureSent = false, TransactionError? reversalError, TransactionError? updateTransactionError, int? accountBalance, String? accountBalanceCurrency, int? balanceDue, String? balanceDueCurrency})
- TransactionResult.fromMap(Map map)
-
factory
Properties
- accountBalance → int?
-
Available on card outcomes; e.g. balance inquiry populates this from the host.
final
- accountBalanceCurrency → String?
-
final
- approved → bool
-
final
- balanceDue → int?
-
Populated when the card outcome includes a balance due amount.
final
- balanceDueCurrency → String?
-
final
- error → TransactionError?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- reversalError → TransactionError?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureSent → bool
-
final
- transactionType → TransactionType
-
final
- updateTransactionError → TransactionError?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited